** set path
cd "C:\SET PATH TO DATA FILES"
set more 1
************************************************************
************************************************************
********************UG STUDY********************************
************************************************************
************************************************************
use "Replication_ug_study.dta", clear
gen age2=age^2
gen female=gender
gen white=(race==3)
replace pid=pid-4
recode pinterest (1=4) (2=3) (3=2) (4=1), gen(interest)
label var age "Age (in years)"
label var age2 "Age-squared"
label var female "Female=1"
label var white "White=1"
label var pid "Party ID (-3=strong D; 3=strong R)"
label var interest "Political Interest (1=not much; 4=very)"

gen repsidewconst=(reppos==0)
label var repsidewconst "Legislator Votes w/District (1=yes)"
gen repsupp=repsidewconst
label var repsupp "Legislator Supports Bill (1=yes)"

gen partyagree=abs(pid)
replace partyagree=partyagree*-1 if siderandom==2
replace partyagree=(partyagree+3)/6
label var partyagree "Party Agreement (0-1)"

gen partyXrepsupp=partyagree*repsidewconst
label var partyXrepsupp "Party Agreement x Legislator Votes w/District"

gen suppbill_post=(suppbill*2/3)-1
gen agreewrep=suppbill_post if repsidewconst==1
replace agreewrep=suppbill_post*-1 if repsidewconst==0

replace suppbill_post=(suppbill_post+1)/2
label var suppbill_post "Support Bill (0-1)"
replace agreewrep=(agreewrep+1)/2
label var agreewrep "Policy Agreement (0-1)"

gen localfocus=abs((forcountryshould/3)-1)
label var localfocus  "Stated Preference for District Focus (0-1)"

gen evaluation=raterep
label var evaluation "Representative Job Rating (1-10)"

gen localfocusXrepsidewconst=localfocus*repsidewconst
label var localfocusXrepsidewconst "Stated Pref. for District Focus x Legislator Votes w/District"

tab localfocus, gen(abstract_)

replace abstract_3=abstract_3+abstract_4
drop abstract_4
label var abstract_1 "Stated Pref. for District Focus: Always Nation"
label var abstract_2 "Stated Pref. for District Focus: Usually Nation"
label var abstract_3 "Stated Pref. for District Focus: Usually/Always District"

gen abstract_1Xrepsidewconst=abstract_1*repsidewconst
label var abstract_1Xrepsidewconst "Stated Pref.: Always Nation x Legislator Votes w/District"
gen abstract_2Xrepsidewconst=abstract_2*repsidewconst
label var abstract_2Xrepsidewconst "Stated Pref.: Usually Nation x Legislator Votes w/District"
gen abstract_3Xrepsidewconst=abstract_3*repsidewconst
label var abstract_3Xrepsidewconst "Stated Pref.: Usually/Always District x Legislator Votes w/District"

reg evaluation localfocus suppbill_post age female white pid interest, r
keep if e(sample)

gen conditions=repsidewconst
replace conditions=conditions+2 if siderandom==2
label var conditions "Conditions (0-3)"
tab conditions, gen(cond_)
drop cond_1

*Balance
mlogit conditions age female white pid interest 

********************************************************
******A1. Summary Statistics*****************************
********************************************************
outsum evaluation localfocus suppbill_post age female white pid interest using "A1_summarystats", bracket ctitle(Farm Subsidy Bill) replace

********************************************************
******A2. Rep. Style --> Evaluations (by Abstract) ******
********************************************************
reg evaluation repsidewconst abstract_2 abstract_3 abstract_2Xrepsidewconst abstract_3Xrepsidewconst, r
lincom repsidewconst, level(90)
lincom repsidewconst+abstract_2Xrepsidewconst, level(90) 
lincom repsidewconst+abstract_3Xrepsidewconst, level(90) 
test abstract_2Xrepsidewconst abstract_3Xrepsidewconst 
outreg using "A2_basicconditional.out", bracket 3aster se replace rdec(3) adec(3) addstat("Joint Significance of Interactions (Prob. > F)", r(p))

********************************************************
******A3. Post-Treatment Bias? *************************
********************************************************
foreach i of varlist cond_* {
foreach c in  age female white pid interest {
gen X`i'_`c'=`i'*`c'
}
}

ologit localfocus partyagree repsupp partyXrepsupp, r
test partyagree repsupp partyXrepsupp
outreg partyagree repsupp partyXrepsupp using "A3_posttreatment.out", bracket 3aster se replace rdec(3) adec(3) addstat(Chi-squred: Treatment Variables, r(chi2), P-value of Chi-squared statistic, r(p)) 

ologit suppbill partyagree repsupp partyXrepsupp, r
test partyagree repsupp partyXrepsupp
outreg partyagree repsupp partyXrepsupp using "A3_posttreatment.out", bracket 3aster se append rdec(3) adec(3) addstat(Chi-squred: Treatment Variables, r(chi2), P-value of Chi-squared statistic, r(p)) 

********************************************************
******T1. Representation Style --> Evaluations **********
********************************************************
reg evaluation repsidewconst, r
lincom repsidewconst 
local est=r(estimate)
sum evaluation
disp `est'/r(sd)
outreg using "T1_directeffects.out", bracket 3aster se replace rdec(3)
reg evaluation repsidewconst agreewrep, r
outreg using "T1_directeffects.out", bracket 3aster se append rdec(3)



************************************************************
************************************************************
********************TESS STUDY******************************
************************************************************
************************************************************
use tess_data.dta, clear

*Demographics
drop if ppstaten==53
gen age=ppage
gen age2=age^2
gen female=ppgender-1
gen white=(ppethm==1)
recode ppeduc (1/8=1) (9=2) (10=3) (11=4) (12=5) (13/14=6), gen(educ)
gen income=ppincimp
recode xideo (1=-3) (2=-2) (3=-1) (4=0) (5=1) (6=2) (7=3) (*=.), gen(ideol)
recode xparty7 (1=3) (2=2) (3=1) (4=0) (5=-1) (6=-2) (7=-3) (*=.), gen(pid)
recode xppa0035 (1=4) (2=3) (3=2) (4=1) (*=.), gen(interest)

label var age "Age (in years)"
label var age2 "Age-squared"
label var female "Female=1"
label var white "White=1"
label var educ "Education (1=no HS; 6=post-grad)"
label var income "Income (1=<$5k; 19=>$175k)"
label var ideol "Ideology (-3=very liberal; 3=very cons)"
label var pid "Party ID (-3=strong D; 3=strong R)"
label var interest "Political Interest (1=not much; 4=very)"
gen strpid=abs(pid)
label var strpid "Strenth of PID (0-3)"

gen repsupp=(xtess013==1 | xtess013==3 | xtess013==5 | xtess013==7)
gen constsupp=(xtess013==1 | xtess013==2 | xtess013==3 | xtess013==4)
gen ownstate=(xtess013==1 | xtess013==2 | xtess013==5 | xtess013==6)

gen repsidewconst=(repsupp==constsupp)

recode q2 (-1=.), gen(forcountry1)
recode q3 (-1=.), gen(forcountry2)

gen forcountryshould=abs(forcountry1-4)

replace forcountry1=abs((forcountry1-4)/3)
label var forcountry1 "Support Country Focus 1 (0-1)"

replace forcountry2=abs((forcountry2-1)/3)
label var forcountry2 "Support Country Focus 2 (0-1)"

gen localfocus=abs(forcountry1-1)

label var localfocus "Support Local Focus (0-1)"

recode q4 (-1=.), gen(trustee)
replace trustee=abs((trustee-1)/3)
label var trustee "Support Trustee Model (0-1)"

recode q5 (-1=.), gen(suppbill_post)
replace suppbill_post=(abs(suppbill_post-4)*2/3)-1

gen agreewrep=suppbill_post if repsupp==1
replace agreewrep=suppbill_post*-1 if repsupp==0

gen agreewconst=suppbill_post if constsupp==1
replace agreewconst=suppbill_post*-1 if constsupp==0

recode q1 (-1=.), gen(suppbill_pre)
replace suppbill_pre=(abs(suppbill_pre-4)*2/3)-1

gen agreewrep_pre=suppbill_pre if repsupp==1
replace agreewrep_pre=suppbill_pre*-1 if repsupp==0

replace suppbill_post=(suppbill_post+1)/2
label var suppbill_post "Support Bill (0-1)"

replace suppbill_pre=(suppbill_pre+1)/2
label var suppbill_pre "Support Bill: Pre-treatment (0-1)"

replace agreewrep=(agreewrep+1)/2
replace agreewrep_pre=(agreewrep_pre+1)/2
replace agreewconst=(agreewconst+1)/2

gen agreewrep_dich=agreewrep>.5
gen agreewrep_dich_pre=agreewrep_pre>.5
label var agreewrep_dich "Dich: Agree with Rep (1=yes)"
label var agreewrep_dich_pre "Dich: Agree with Rep [pre-stimulus] (1=yes)"


gen raterep=q6-1
label var raterep "Rate Job as Representative"
gen feelperson=q7-1
label var feelperson "Feel about Senator as Person (0=negative;10=positive)"	
gen affectvote=q8-1
label var affectvote "More or Less Likely to Vote for? (0=much less likely;10=much more likely)"	
gen ratecongress=q9-1
label var ratecongress "Approve of How Congress Works? (0=strongly disapprove;10=strongly approve)"

gen localfocusXrepsidewconst=localfocus*repsidewconst

tab localfocus, gen(abstract_)
replace abstract_3=abstract_3+abstract_4
drop abstract_4
gen abstract_1Xrepsidewconst=abstract_1*repsidewconst
gen abstract_2Xrepsidewconst=abstract_2*repsidewconst
gen abstract_3Xrepsidewconst=abstract_3*repsidewconst

gen evaluation=raterep

gen repsuppXconstsupp=repsupp*constsupp
gen constsuppXown=constsupp*ownstate 
gen repsuppXown=repsupp*ownstate 
gen repsidewconstXown=repsidewconst*ownstate 
gen agreewrepXown=agreewrep*ownstate 
gen agreewrepXown_pre=agreewrep_pre*ownstate 
gen repsuppXconstsuppXown=constsupp*repsupp*ownstate 

gen agreeXstyle=agreewrep*repsidewconst

gen agreeXstyle_pre=agreewrep_pre*repsidewconst

gen agreepol=(agreewrep==0 | agreewrep==1)
gen agreepolXstyle=agreepol*repsidewconst
gen agree_strA=(agreewrep==1)
gen agree_strD=(agreewrep==0)
gen agree_strAXstyle=agree_strA*repsidewconst
gen agree_strDXstyle=agree_strD*repsidewconst

gen agreewconstXstyle=agreewconst*repsidewconst

gen strsupp=(suppbill_post==1 | suppbill_post==0)
label var strsupp "Strong policy position = 1"
rename q10 mot_goodpolicy
rename q11 mot_reelect
rename q12 mot_allamer
rename q13 mot_influence
rename q14 mot_personal
rename q15 mot_specialint
rename q16 mot_constit
rename q17 mot_pander
label var mot_goodpolicy "Motive: Make Good Policy (1-7)"
label var mot_allamer "Motive: Help All Americans (1-7)"
label var mot_constit "Motive: Help Constituents (1-7)"
label var mot_reelect "Motive: Reelection (1-7)"
label var mot_influence "Motive: Increase Political Influence (1-7)"
label var mot_specialint "Motive: Special Interest Influence (1-7)"
label var mot_pander "Motive: Pander to Voters (1-7)"
label var mot_personal "Motive: Personal Preferences (1-7)"

reg evaluation trustee localfocus suppbill_pre suppbill_post age female white pid interest educ income mot_allamer mot_constit mot_reelect mot_influence mot_pander, r
keep if  e(sample)

foreach i in age female white pid interest educ income {
gen focusX`i'=repsidewconst*`i'
local label : variable label `i'
label var focusX`i' "Legislator Votes w/District x `label'"
}

gen conditions=xtess013
label var conditions "Conditions (1-8)"
tab conditions, gen(cond_)
drop cond_1


* LABELS
label var repsupp "Legislator Supports Bill (1=yes)"
label var constsupp "Constituents Support Bill (1=yes)"

label var repsidewconst "Legislator Votes w/District (1=yes)"
label var agreewrep "Policy Agreement (0-1)"
label var agreeXstyle "Policy Agreement x Legislator Votes w/District"
label var localfocus  "Stated Preference for District Focus (0-1)"
label var localfocusXrepsidewconst "Stated Pref. for District Focus x Legislator Votes w/District"
label var abstract_1 "Stated Pref. for District Focus: Always Nation"
label var abstract_1Xrepsidewconst "Stated Pref.: Always Nation x Legislator Votes w/District"
label var abstract_2 "Stated Pref. for District Focus: Usually Nation"
label var abstract_2Xrepsidewconst "Stated Pref.: Usually Nation x Legislator Votes w/District"
label var abstract_3 "Stated Pref. for District Focus: Usually/Always District"
label var abstract_3Xrepsidewconst "Stated Pref.: Usually/Always District x Legislator Votes w/District"
label var evaluation "Representative Job Rating (0-10)"

label var agreepol "Strong Policy Preference (1=yes)"
label var agreepolXstyle "Strong Policy Preference x Legislator Votes w/District"

label var agreewrep_pre "Policy Agreement [Pre] (0-1)"
label var agreeXstyle_pre "Policy Agreement [Pre] x Legislator Votes w/District"

label var agreewconst "Agree with Constituents (0-1)"

label var ownstate "Legislator from R's Own State (1=yes)"
label var repsidewconstXown "Legislator from R's Own State x Legislator Votes w/District"
label var agreewrepXown "Legislator from R's Own State x Policy Agreement"
label var agreewrepXown_pre "Legislator from R's Own State x Policy Agreement [Pre]"
label var constsuppXown "Legislator from R's Own State x Constituents Support Bill"
label var repsuppXown "Legislator from R's Own State x Representative Supports Bill"
label var repsuppXconstsupp "Constituents Support Bill x Representative Supports Bill"
label var repsuppXconstsuppXown "Constituents Support Bill x Representative Supports Bill x Own State"


********************************************************
******A1. Summary Statistics*****************************
********************************************************
*Balance
mlogit conditions age female white pid interest educ income suppbill_pre
outsum evaluation localfocus suppbill_post age female white pid interest educ income using "A1_summarystats", bracket ctitle(Nuclear Energy Bill) append

********************************************************
******A2. Rep. Style --> Evaluations (by Abstract) ******
********************************************************
reg evaluation repsidewconst abstract_2 abstract_3 abstract_2Xrepsidewconst abstract_3Xrepsidewconst, r
lincom repsidewconst, level(90)
lincom repsidewconst+abstract_2Xrepsidewconst, level(90)
lincom repsidewconst+abstract_3Xrepsidewconst, level(90)
test abstract_2Xrepsidewconst abstract_3Xrepsidewconst
outreg using "A2_basicconditional.out", bracket 3aster se append rdec(3) adec(3) addstat("Joint Significance of Interactions (Prob. > F)", r(p))

********************************************************
******A3. Post-Treatment Bias? *************************
********************************************************
foreach i of varlist cond_* {
foreach c in  age female white pid interest educ income suppbill_pre {
gen X`i'_`c'=`i'*`c'
}
}

ologit suppbill_post repsupp constsupp ownstate, r
test repsupp constsupp ownstate 
outreg using "A3_posttreatment.out", bracket 3aster se append rdec(3) adec(3) addstat(Chi-squred: Treatment Variables, r(chi2), P-value of Chi-squared statistic, r(p)) 

ologit suppbill_post repsupp constsupp ownstate repsuppXconstsupp repsuppXown constsuppXown repsuppXconstsuppXown, r
test repsupp constsupp ownstate repsuppXconstsupp repsuppXown constsuppXown repsuppXconstsuppXown 
outreg using "A3_posttreatment.out", bracket 3aster se append rdec(3) adec(3) addstat(Chi-squred: Treatment Variables, r(chi2), P-value of Chi-squared statistic, r(p)) 

********************************************************
******T1. Representation Style --> Evaluations **********
********************************************************
reg evaluation repsidewconst, r
lincom repsidewconst 
local est=r(estimate)
sum evaluation
disp `est'/r(sd)
outreg using "T1_directeffects.out", bracket 3aster se append rdec(3)

reg evaluation repsidewconst agreewrep, r
outreg using "T1_directeffects.out", bracket 3aster se append rdec(3)

reg evaluation repsidewconst agreewrep_pre, r
outreg using "T1_directeffects.out", bracket 3aster se append rdec(3)

********************************************************
**********************T2. Moderators *******************
********************************************************
reg evaluation repsidewconst ownstate repsidewconstXown, r
lincom repsidewconst + repsidewconstXown 
outreg using "T2_own_moderation.out", bracket 3aster se replace rdec(3)

reg evaluation repsidewconst agreewrep ownstate repsidewconstXown agreewrepXown, r
outreg using "T2_own_moderation.out", bracket 3aster se append rdec(3)

reg evaluation repsidewconst agreewrep_pre ownstate repsidewconstXown agreewrepXown_pre, r
outreg using "T2_own_moderation.out", bracket 3aster se append rdec(3)

********************************************************
******A5. Treatments --> Motives ************************
********************************************************
foreach i in allamer constit reelect influence pander {
egen std_`i'=std(mot_`i')
reg std_`i' repsidewconst, r
if "`i'"=="allamer"{
outreg using "A5_motives_std.out", bracket 3aster se replace rdec(3)
}
else{
outreg using "A5_motives_std.out", bracket 3aster se append rdec(3)
}
}

foreach i in allamer constit reelect influence pander {
reg std_`i' repsidewconst agreewrep repsidewconstXown agreewrepXown ownstate, r
lincom repsidewconst + repsidewconstXown 
lincom agreewrep + agreewrepXown 
if "`i'"=="allamer"{
outreg repsidewconst agreewrep repsidewconstXown agreewrepXown ownstate using "A6A_motivesbyownstate_std.out", bracket 3aster se replace rdec(3)
}
else{
outreg repsidewconst agreewrep repsidewconstXown agreewrepXown ownstate using "A6A_motivesbyownstate_std.out", bracket 3aster se append rdec(3)
}
}
**** using Pre-treatment Policy measure
foreach i in allamer constit reelect influence pander {
reg std_`i' repsidewconst agreewrep_pre repsidewconstXown agreewrepXown_pre ownstate, r
if "`i'"=="allamer"{
outreg using "A6B_motivesbyownstate_std_pre.out", bracket 3aster se replace rdec(3)
}
else{
outreg using "A6B_motivesbyownstate_std_pre.out", bracket 3aster se append rdec(3)
}
}

foreach i in allamer constit reelect influence pander {
reg std_`i' repsidewconst agreewrep repsidewconstXown agreewrepXown ownstate, r
lincom repsidewconst+repsidewconstXown 
lincom agreewrep+agreewrepXown 
}


*** FIGURE 1 DATA
foreach i in allamer constit reelect influence pander {
reg std_`i' repsidewconst agreewrep repsidewconstXown agreewrepXown ownstate, r

lincom repsidewconst 
matrix item=r(estimate)
matrix itemse=(r(se)*1.65)
lincom repsidewconst+repsidewconstXown
matrix item=item\r(estimate)
matrix itemse=itemse\(r(se)*1.65)
lincom agreewrep
matrix item=item\r(estimate)
matrix itemse=itemse\(r(se)*1.65)
lincom agreewrep+agreewrepXown
matrix item=item\r(estimate)
matrix itemse=itemse\(r(se)*1.65)
if "`i'"=="allamer"{
matrix full=item
matrix fullse=itemse
}
else{
matrix full=full,item
matrix fullse=fullse,itemse
}
}
matrix list full
matrix list fullse


****************************************************
**** 2010 CCES *************************************
****************************************************
clear all
use "cces2010.dta", clear
recode treatyal398b (1=1) (2=0), gen(reppos)
recode cc332c (1=1) (2=0) (*=.), gen(suppbill)
recode treatyal398 (1=1) (2=0), gen(constsupp)
gen condition = reppos+10*constsupp
gen repsidewconst=(reppos==constsupp)
gen agreewrep=suppbill if reppos==1
replace agreewrep=abs(suppbill-1) if reppos==0

gen yal398=yal398a
replace yal398=yal398b if yal398a>100
replace yal398=. if yal398>100
gen evaluation=yal398/10
label var evaluation "Representative Job Rating (0-10)"

*Race
tab v211, gen(race)
gen white=race1
*Gender
gen female=v208-1
*Age
gen age=2010-v207
*Family Income
gen income=v246
drop if income>14
label var income "Income (1=<10k; 14=>150k)"
*Education
gen educ=v213
recode v244 (1=4) (2=3) (3=2) (4=1) (*=.), gen(interest)
label var interest "Interest in News/Public Affairs (1=hardly at all;4=most of the time)"
recode v212d (1=3) (2=2) (3=1) (4 8=0) (5=-1) (6=-2) (7=-3) (*=.), gen(pid)

label var suppbill "Support Bill (0-1)"
label var pid "Party ID (-3=strong D; 3=strong R)"
label var age "Age (in years)"
label var white "White=1"
label var educ "Education (1=no HS; 6=post-grad)"
label var female "Female=1"
label var evaluation "Representative Job Rating (0-10)"
label var repsidewconst "Legislator Votes w/District (1=yes)"
label var agreewrep "Policy Agreement (0-1)"

reg evaluation repsidew agreewrep age female white pid interest educ income, r
keep if e(sample)

mlogit condition suppbill age female white pid interest educ income 
outsum evaluation suppbill age female white pid interest educ income using "A1_summarystats", bracket ctitle(American Clean Energy and Security Act) append
reg evaluation repsidewconst, r
outreg using "A4_directeffects_follow_up.out", bracket 3aster se replace rdec(3)
reg evaluation repsidewconst agreewrep, r
outreg using "A4_directeffects_follow_up.out", bracket 3aster se append rdec(3)

**********************************
***** MECHANICAL TURK STUDY
**********************************
use "mturk.dta", clear
gen dist_supp=.
replace dist_supp=1 if district_supp=="District Support"
replace dist_supp=0 if district_supp=="District Oppose"

gen suppbill=abs(stem_cell-5)/4

gen rep_supp=.
replace rep_supp=1 if rep_vote=="For"
replace rep_supp=0 if rep_vote=="Against"
gen repsidewdist=(rep_supp==dist_supp)
gen condition=dist_supp+10*rep_supp

gen agreewrep=suppbill if rep_supp==1
replace agreewrep=abs(suppbill-1) if rep_supp==0

egen pid=rmean(pid_dem pid_rep pid_lean)

recode r_white (1=1) (*=0)
rename r_white white
rename eval_rep evaluation
rename repsidewdist repsidewconst 
rename gender female

gen age=2010-yob
label var suppbill "Support Bill (0-1)"
label var pid "Party ID (-3=strong D; 3=strong R)"
label var age "Age (in years)"
label var white "White=1"
label var educ "Education (1=no HS; 6=post-grad)"
label var female "Fe male=1"
label var evaluation "Representative Job Rating (0-10)"
label var repsidewconst "Legislator Votes w/District (1=yes)"
label var agreewrep "Policy Agreement (0-1)"

reg evaluation repsidewconst agreewrep age female white pid educ , r
keep if e(sample)

mlogit condition suppbill age female white pid educ

outsum evaluation suppbill age female white pid educ using "A1_summarystats", bracket ctitle(Stem Cell Research Bill) append 

reg evaluation repsidewconst, r
outreg using "A4_directeffects_follow_up.out", bracket 3aster se append rdec(3)
reg evaluation repsidewconst agreewrep, r
outreg using "A4_directeffects_follow_up.out", bracket 3aster se append rdec(3)
reg evaluation repsidewconst agreewrep age female white pid educ, r
outreg using "A4_directeffects_follow_up.out", bracket 3aster se append rdec(3)
